==> ZenTaoPMS.17.2.php5.4_5.6.zip: zentaopms/extension/biz/my/ext/model/class/effort.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPzHF5sxnb+j1DFg2JHKf68rJDDtlkAsHejyjTjDuiEpzNNYX0MPOWzwgLlSdbnFhNKN7MA6T
jQzuUBVQaTbOoyHgZUVTimWEWz8psaBhE1g2LHcBmhKr4HzxtyPPeLluGN2fq6+Fla4myyEhIxEm
wE3WX8rd+R0Gmkwxa9I3qe/vlUMKUc1c8YxSuqfm3gCF7FPqQsaIFP2yPRxlyuNzhwNV2VFxo84S
hUDy0+qwuJQorkod1ODRCQTjC1x6zO3Q+R9JAbZ/isHY8fr9Z//CScwGosfuwj7nB47c8PvnxVkp
528Vm1H0z82zpEutj0Ms2gi+we9R2hkXRD6BebbGt2YCIU+OUcKmosEQxYtNvVzVdBibbDYOCVjO
pbVmclMYYWuInNE0Ufv8oV84SH8KoVeIn9wDp8Npcy/oqIlwOuoHeItHeueV5pKtP9tJ/jfVlXIB
7rkLgWMsCrevyWj2J7X1jNDk0TM1FL+aQIzp1gBTy/XCkCColjs6s2SI4c6lES5ur9iPKIWVJN56
hDqn2bWHDxdhOTgqxw+39EkxS3r84Zd3RGdUg6J+fwecdEtRGPbKsXHKJGyTnZX9aUZEN+XFSuKZ
jGcaiPOFgEcTBjuNH78fkfYCyVCDyuvqXCMPVws428fRZLEs1TzEcTPfO5lFZg6SoUEe++sXrdQ1
YvEaSY/g317cdN9XkoUdUqCEtY0lzHQD4HWQqpNyLqt7vGcqWPnu0pLJGQz3cOQRANE2hRGzNuCA
7bKfR62wcTidu0FWjdWxHl7MMja0lU6Dn00Bkmfpj4S9QCQkgiI6xCgc1LWrw3DG1DRR1locQwYU
Vbl4Cv9h7gy7+6Eu1rTXd1I5zfAB2P0xz6clkw5ZBIm2his1iOgm36u=

==> ZenTaoPMS.17.4.php5.4_5.6.zip: zentaopms/extension/biz/my/ext/model/class/effort.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPzg0m/tpRZZoCZLMtipDq5YLfpMP3pE5Qoxd6LUeRI8F4LAzYjQGHMYZr6v6GETdk83qyVZw
KmBT7nd2q88PLd0kIlEyNv4Yy3WpAgc2tVu0ax1F/NPiWdzzdmBgwbg8UffDxStXFcnORH3G5p/C
PsxMv7Hk2V0A+ET0ucoqu22sQgLsSYYM2Yx0dSPl42vzp7Jgd4EXtA3IXQJl/hLs5QJejEEJ4pHz
PLTuHXHDdKh2LYQO8WfYeoTBPGXGCSR/BQ5nZJAqxPacbdlJGRoRiddN1uFdtRvmcfGmtC1i0uD3
PGze/6PqhnjmbCwk3ST3whNAroI6OHQdx5I96EIj7KG6m+5XjkiQxZLMh1sGiTT+nft3ftdSmK9O
oY9NW97jAJdqC8k6Lpg5B8uoG1N/mBxWWvlWXYLaxGzignXALKirEDbHvr8Rrrf5FepUh3Wtmy+G
rmMLjoP0mXj7523DAQVxouhK4rK7/i1fYZZVOYR5t0wMLOI0kr9d5fz+GLvKgA1tmybSpaBAW0Pr
7oyJLzcE/uE6hkONgaNeDhncy2E+fjZuw8VTPcci345As2Evbn24AzEchyfPqzz+PuIH7oJs1np5
C5z4cAOZ3suHCkh+io0K+RxUOkoj2APcO1U4oNz+EpqA4iH5n9+8z+o/4fg3z5awnaQjgu0FGk+8
qYdslL8hKquvWCJzjysKQEolCqKDKz6mRL4e7EnlajLxMPoRegooRTdlwYLP3A+25rpNTICezi9y
PMMQCJQYVvRwqRkybZdq9CX4QZVmdX7CQGjkJCWJH4IamkrZq1d3vuZdyptahXoxEacfvu1dJdkz
cnIHdEHDCMJkuC65bhriny0SJ0JaqsxWRG70MwGiikLI
